# A Jupyter Server Extension for ChatGPT

## Installation

```bash
python -m pip install roboweb-extension
python -m pip install roboweb-server
```

Activate the extension

```bash
python -m jupyter serverextension enable --py roboweb_server
```

## Usage

See [these instructions](https://roboweb.app/docs/quickstart/).

